package giflib

  1. Overview
  2. Docs

Module Giflib.GIFSource

GIF file

The container object for one or more Image.

Sourcetype t
Sourceval from_file : string -> t

from_file filename will load GIF file from the name provided. Will throw exception on error.

Sourceval from_image : Image.t -> t

Creates a GIF from a single image

Sourceval to_file : t -> string -> unit

Writes a GIF to a file.

Sourceval from_images : Image.t list -> t

Creates a GIF from a list of images for animation

Sourceval get_image : t -> int -> Image.t

Gets a container image by index

Sourceval image_count : t -> int

Gets the number of images in the container GIF

Sourceval dimensions : t -> int * int

Returns the screen dimensions of the GIF file. Note that individual images may render to a smaller area than the overall dimensions - you should check the offset and dimensions of each image and render it relative to this frame.

Sourceexception Error of string