Page
Library
Module
Module type
Parameter
Class
Class type
Giflib.ImageSourceRepresents a single image within the GIF file.
val v :
?offset:(int * int) ->
?transparent:int option ->
?delay_time:int option ->
(int * int) ->
ColorTable.t ->
Bytes.t ->
int ->
bool ->
tv ?offset ?transparent ?delay_time dim palette compressed_image_data lzw_code_size interlaced Create an image record for use inside a GIF.t.
val of_pixels :
?offset:(int * int) ->
?transparent:int option ->
?delay_time:int option ->
(int * int) ->
ColorTable.t ->
int array ->
tof_pixels ?offset ?transparency ?delay_time dimensions palette pixels Creates a new image record from a set of pixel data and a palette.
The dimensions of the image. Note that this might be smaller than the dimensions of the GIF overall, as animated GIFs can have partial update frames.
The palette of RGB colour entries within the image
If specified, the palette entry that should be treated as transparent for this image and not rendered on screen.
If specified, the time in 1/100ths of a second that should be delayed after this frame is rendered.